@@ -83,6 +83,5 @@ def koshi_goldstein(
                 ]
         case _:
             raise NotImplementedError(
-                "The matrix type is not implemented. Please use one of the following: "
-                f"{[matrix_type.name for matrix_type in MatrixType]}"
+                "The matrix type is not yet implemented."
             )
